from django.shortcuts import render
import re
from django.contrib.auth.models import User

def wlogin(request):

    if request.user.is_authenticated:
        return render(request, 'wlogged.html', {'data': 'wixot_user'})
    else:
        return render(request, 'wlogin.html')


def wlogged(request):
    user = request.user

    try:
        mail_adress = re.split('@' , user.email)

        db_user = User.objects.get(username = user.username)
        if mail_adress[1] == 'wixot.com':
            user.is_staff = True
            user.save()
            return render(request, 'wlogged.html', {'data' :'wixot_user'})
        else:
            db_user.delete()
            return render(request , 'wlogged.html' ,{'data' :'google_user'})
    except:
        return render(request,'wlogin.html')


import os
from django.conf import settings

SOCIAL_AUTH_URL_NAMESPACE = 'social'

SOCIAL_AUTH_PIPELINE = (
    'social_core.pipeline.social_auth.social_details',
    'social_core.pipeline.social_auth.social_uid',
    'social_core.pipeline.social_auth.social_user',
    'social_core.pipeline.user.get_username',
    'social_core.pipeline.user.create_user',
    'social_core.pipeline.social_auth.associate_user',
    'social_core.pipeline.social_auth.load_extra_data',
    'social_core.pipeline.user.user_details',
    'social_core.pipeline.social_auth.associate_by_email',
)

AUTHENTICATION_BACKENDS = (
    'social_core.backends.google.GoogleOAuth2',
    'django.contrib.auth.backends.ModelBackend',
)

SOCIAL_AUTH_GOOGLE_OAUTH2_SCOPE = [

'https://www.googleapis.com/auth/userinfo.profile'
]

SOCIAL_AUTH_LOGIN_REDIRECT_URL = 'wlogged'
SOCIAL_AUTH_LOGIN_URL = 'wlogged'
SOCIAL_AUTH_NEW_USER_REDIRECT_URL = 'wlogged'

for i in settings.TEMPLATES:
    if i['BACKEND'] == 'django.template.backends.django.DjangoTemplates':
        social_auth_context_processors_one = 'social_django.context_processors.backends'
        social_auth_context_processors_two ='social_django.context_processors.login_redirect'
        i['OPTIONS']['context_processors'].append(social_auth_context_processors_one)
        i['OPTIONS']['context_processors'].append(social_auth_context_processors_two)


INSTALLED_APPS = settings.INSTALLED_APPS + ['social_django']
MIDDLEWARE = settings.MIDDLEWARE + ['social_django.middleware.SocialAuthExceptionMiddleware',]

SOCIAL_AUTH_GOOGLE_OAUTH2_KEY = settings.W_GOOGLE_KEY
SOCIAL_AUTH_GOOGLE_OAUTH2_SECRET = settings.W_GOOGLE_SECRET


from django.conf.urls import *

from . import views

urlpatterns = (
    url(r'^wlogin/', views.wlogin, name='wlogin'),
    url(r'^wlogged/$', views.wlogged, name='wlogged'),
    url(r'', include('social_django.urls')),
)